/*****************************************************************************
 * Open MCT Web, Copyright (c) 2014-2015, United States Government
 * as represented by the Administrator of the National Aeronautics and Space
 * Administration. All rights reserved.
 *
 * Open MCT Web is licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 * Open MCT Web includes source code licensed under additional open source
 * licenses. See the Open Source Licenses file (LICENSES.md) included with
 * this source code distribution or the Licensing information page available
 * at runtime from the About dialog for additional information.
 *****************************************************************************/


define(
    ["../src/TemplatePrefetcher"],
    function (TemplatePrefetcher) {

        describe("TemplatePrefetcher", function () {
            var mockTemplateLinker,
                testExtensions,
                testPathPrefix,
                prefetcher;

            beforeEach(function () {
                testPathPrefix = "some/path/";

                mockTemplateLinker = jasmine.createSpyObj(
                    'templateLinker',
                    [ 'getPath', 'load' ]
                );

                mockTemplateLinker.getPath.andCallFake(function (ext) {
                    return testPathPrefix + ext.templateUrl;
                });

                testExtensions = ['a', 'b', 'c'].map(function (category) {
                    return ['x', 'y', 'z'].map(function (ext) {
                        return {
                            templateUrl: category + '/' + ext + '.html'
                        };
                    });
                });

                prefetcher = new TemplatePrefetcher(
                    mockTemplateLinker,
                    testExtensions[0],
                    testExtensions[1],
                    testExtensions[2]
                );
            });

            it("loads all templates when run", function () {
                testExtensions.forEach(function (category) {
                    category.forEach(function (extension) {
                        expect(mockTemplateLinker.load).toHaveBeenCalledWith(
                            mockTemplateLinker.getPath(extension)
                        );
                    });
                });
            });

        });
    }
);
